@@ -93,13 +93,14 @@ get.snowball <- function(pkg, date, include.suggests=FALSE, force.install=FALSE)
             
   # Note about saving (shown after all dependency messages, only once per groundhog.library call)
     if (is.null(.pkgenv[['snowball.note.shown']]) || .pkgenv[['snowball.note.shown']] == FALSE) {
-        message2("We will save the information below for next time you load those same package versions")
+        message2("Finding the version of all packages needed for groundhog day: ",format(date, "%Y-%m-%d"))
+        message1("We will save the results, using the same date in the future will be faster")
         .pkgenv[['snowball.note.shown']] <- TRUE
     }
   
                
   # Message when creating new snowball (shown before dependency resolution)
-        message1("Finding the version of all packages that '", pkg, "' needs for requested date: '", date, "'")
+        message1("Processing: '", pkg,"'")
             
   # 1 Get dependencies
   dep12 <- get.all.dependencies(pkg, date, include.suggests = include.suggests)
